/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayForm, {ClayInput} from '@clayui/form';
import {useIsMounted} from '@liferay/frontend-js-react-web';
import React, {useCallback, useState} from 'react';

import parseFile from './FileParsers';
import {FILE_SCHEMA_EVENT, IMPORT_FILE_FORMATS} from './constants';

function FileUpload({portletNamespace}) {
	const isMounted = useIsMounted();
	const [errorMessage, setErrorMessage] = useState();

	const onFileChange = useCallback(
		(event) => {
			const {files} = event.target;
			if (files?.length === 0) {
				return Liferay.fire(FILE_SCHEMA_EVENT, {
					schema: null,
				});
			}

			const onComplete = (schema) => {
				Liferay.fire(FILE_SCHEMA_EVENT, {
					schema,
				});
			};

			const onError = () => {
				if (isMounted()) {
					setErrorMessage(Liferay.Language.get('unexpected-error'));
				}
			};

			return parseFile({
				file: files[0],
				onComplete,
				onError,
			});
		},
		[isMounted]
	);

	const inputNameId = `${portletNamespace}importFile`;

	return (
		<ClayForm.Group className={errorMessage ? 'has-error' : ''}>
			<label htmlFor={inputNameId}>{Liferay.Language.get('file')}</label>

			<ClayInput
				accept={IMPORT_FILE_FORMATS.map((format) => `.${format}`).join(
					', '
				)}
				id={inputNameId}
				name={inputNameId}
				onChange={onFileChange}
				type="file"
			/>

			{errorMessage && (
				<ClayForm.FeedbackGroup>
					<ClayForm.FeedbackItem>
						<ClayForm.FeedbackIndicator symbol="exclamation-full" />

						{errorMessage}
					</ClayForm.FeedbackItem>
				</ClayForm.FeedbackGroup>
			)}
		</ClayForm.Group>
	);
}

export default FileUpload;
