/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayDropDown from '@clayui/drop-down';
import ClayIcon from '@clayui/icon';
import classnames from 'classnames';
import PropTypes from 'prop-types';
import React, {useCallback} from 'react';

const ImportMappingDropdownItem = ({item, onClick, selectedItem}) => {
	const selected = selectedItem === item.value;

	const onItemClick = useCallback(() => {
		if (!selected) {
			onClick(item.value);
		}
	}, [item, onClick, selected]);

	return (
		<ClayDropDown.Item
			className="align-items-center d-flex justify-content-between"
			onClick={onItemClick}
		>
			<span className={classnames({'text-muted': selected})}>
				{item.label}
			</span>

			{selected && <ClayIcon className="text-success" symbol="check" />}
		</ClayDropDown.Item>
	);
};

export const ImportFieldPropType = {
	label: PropTypes.string.isRequired,
	required: PropTypes.bool,
	value: PropTypes.string.isRequired,
};

ImportMappingDropdownItem.propTypes = {
	item: PropTypes.shape(ImportFieldPropType).isRequired,
	onClick: PropTypes.func.isRequired,
	selectedItem: PropTypes.string,
};

export default ImportMappingDropdownItem;
